(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     97438,       2344]
NotebookOptionsPosition[     94818,       2251]
NotebookOutlinePosition[     95206,       2267]
CellTagsIndexPosition[     95163,       2264]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Phenotypic plasticity with two predators", "Title",
 FontFamily->"Gill Sans MT",
 FontSize->28]], "Input",
 CellChangeTimes->{{3.732012860695222*^9, 3.732012875479105*^9}, {
  3.732012965343412*^9, 3.7320129986606994`*^9}, {3.7320130803617587`*^9, 
  3.7320130908634586`*^9}, {3.7379530814976454`*^9, 3.7379530917633924`*^9}}],

Cell[CellGroupData[{

Cell["Model definition: equations", "Section",
 CellChangeTimes->{{3.7320131433574667`*^9, 3.7320131762390223`*^9}, {
  3.732013247562898*^9, 3.7320132478616414`*^9}, {3.7379538505269356`*^9, 
  3.737953851606701*^9}}],

Cell[CellGroupData[{

Cell["Per capita prey and predator growth rates", "Subsection",
 CellChangeTimes->{{3.732013240594036*^9, 3.7320132528460965`*^9}, {
  3.737953853871257*^9, 3.73795386524718*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"wx1", "=", 
   RowBox[{
    RowBox[{"r1", "*", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x1", "[", "t", "]"}], "+", 
          RowBox[{"x2", "[", "t", "]"}]}], ")"}], "/", "k"}]}], ")"}]}], "-", 
    RowBox[{"a1", "*", 
     RowBox[{
      RowBox[{"y1", "[", "t", "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"h1", "*", "a1", "*", 
         RowBox[{"x1", "[", "t", "]"}]}]}], ")"}]}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wx2", "=", 
   RowBox[{
    RowBox[{"r2", "*", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x1", "[", "t", "]"}], "+", 
          RowBox[{"x2", "[", "t", "]"}]}], ")"}], "/", "k"}]}], ")"}]}], "-", 
    RowBox[{"a2", "*", 
     RowBox[{
      RowBox[{"y2", "[", "t", "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"h2", "*", "a2", "*", 
         RowBox[{"x2", "[", "t", "]"}]}]}], ")"}]}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wy1", "=", 
   RowBox[{
    RowBox[{"e1", "*", "a1", "*", 
     RowBox[{
      RowBox[{"x1", "[", "t", "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"h1", "*", "a1", "*", 
         RowBox[{"x1", "[", "t", "]"}]}]}], ")"}]}]}], "-", "d"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wy2", "=", 
   RowBox[{
    RowBox[{"e2", "*", "a2", "*", 
     RowBox[{
      RowBox[{"x2", "[", "t", "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"h2", "*", "a2", "*", 
         RowBox[{"x2", "[", "t", "]"}]}]}], ")"}]}]}], "-", "d"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.63384321232058*^9, 3.6338433693303194`*^9}, {
   3.6338434363900757`*^9, 3.6338435839454746`*^9}, {3.633843855171001*^9, 
   3.6338438893062057`*^9}, {3.6338439225998735`*^9, 
   3.6338439254738426`*^9}, {3.63384423383683*^9, 3.633844248011423*^9}, {
   3.633844381197025*^9, 3.633844382929221*^9}, {3.6338445033561444`*^9, 
   3.633844669069685*^9}, {3.6338447287076445`*^9, 3.633844795644618*^9}, {
   3.6338639053962603`*^9, 3.6338639661641936`*^9}, {3.6338644573253937`*^9, 
   3.633864457496523*^9}, {3.6338652128421335`*^9, 3.6338652553793373`*^9}, {
   3.6338653057188916`*^9, 3.633865317327881*^9}, {3.6338653598380623`*^9, 
   3.633865360071212*^9}, {3.633866820789173*^9, 3.633866921552353*^9}, {
   3.633866988560366*^9, 3.633867017960555*^9}, {3.63386708196548*^9, 
   3.633867148123923*^9}, {3.6338671983243923`*^9, 3.633867201069262*^9}, {
   3.6338678065952525`*^9, 3.633867810354806*^9}, 3.6338685288625336`*^9, {
   3.633868628004609*^9, 3.6338686368366556`*^9}, {3.6367855480930233`*^9, 
   3.6367855540379934`*^9}, {3.6376491541000304`*^9, 
   3.6376491656250772`*^9}, {3.637649664483103*^9, 3.637649671001433*^9}, {
   3.6376509645380573`*^9, 3.6376509668946733`*^9}, {3.6376512780099163`*^9, 
   3.6376513223298707`*^9}, {3.637651357659622*^9, 3.6376513603775377`*^9}, {
   3.6376514072075205`*^9, 3.6376514130496483`*^9}, {3.637651513220151*^9, 
   3.6376515175249753`*^9}, {3.6387040060553684`*^9, 3.638704013604545*^9}, {
   3.6387040936927943`*^9, 3.63870409992381*^9}, {3.6387047576350555`*^9, 
   3.6387047612495937`*^9}, {3.6388536263414373`*^9, 
   3.6388536424674225`*^9}, {3.6391128555126867`*^9, 
   3.6391128559259896`*^9}, {3.6391132293611097`*^9, 3.6391132299505396`*^9}, 
   3.6392000589998116`*^9, {3.639205572329553*^9, 3.639205576152357*^9}, {
   3.6392057404634466`*^9, 3.639205759184395*^9}, {3.63922000706166*^9, 
   3.639220035616212*^9}, {3.6393734393450537`*^9, 3.6393734406229815`*^9}, {
   3.6393754265427494`*^9, 3.6393754267979307`*^9}, 3.639383271151599*^9, {
   3.640083433268077*^9, 3.6400834409974127`*^9}, {3.6400835047282248`*^9, 
   3.6400835766456437`*^9}, {3.640084942127364*^9, 3.6400849491712065`*^9}, {
   3.640084998548346*^9, 3.640085043366728*^9}, {3.640085113864944*^9, 
   3.6400851496564064`*^9}, 3.640085250995848*^9, {3.6400852916629915`*^9, 
   3.6400853299140267`*^9}, {3.640085809654846*^9, 3.640085816309356*^9}, {
   3.6400858684328933`*^9, 3.640085887104669*^9}, {3.6400864882669773`*^9, 
   3.640086506143236*^9}, {3.640086543222749*^9, 3.640086543375832*^9}, {
   3.640086574775419*^9, 3.6400865749355507`*^9}, {3.6400868295465946`*^9, 
   3.640086829753707*^9}, {3.6403200960184793`*^9, 3.640320119258486*^9}, {
   3.640320153968317*^9, 3.640320211979248*^9}, {3.640320757793579*^9, 
   3.6403207973343525`*^9}, {3.6403208309917746`*^9, 3.640320858438243*^9}, {
   3.640321187793438*^9, 3.6403211893614855`*^9}, {3.640321303530441*^9, 
   3.640321340713526*^9}, 3.6403213755310163`*^9, {3.6403214202241683`*^9, 
   3.6403214203742685`*^9}, {3.640321502365585*^9, 3.640321515467422*^9}, {
   3.640321686143569*^9, 3.640321686245637*^9}, {3.640321885879883*^9, 
   3.640321888161436*^9}, {3.640321928557955*^9, 3.6403219533998766`*^9}, {
   3.6403221913109407`*^9, 3.640322193644531*^9}, {3.64032302990919*^9, 
   3.640323096635645*^9}, {3.640323135207919*^9, 3.6403231374944773`*^9}, {
   3.6403235087313633`*^9, 3.640323516464631*^9}, {3.640323784244042*^9, 
   3.6403237963753357`*^9}, {3.6406706945212193`*^9, 
   3.6406706947313585`*^9}, {3.640671529670863*^9, 3.640671553866048*^9}, {
   3.640676626200308*^9, 3.640676646556924*^9}, {3.640676838645421*^9, 
   3.6406768388005257`*^9}, {3.6412686918884706`*^9, 3.641268696801464*^9}, {
   3.641642768192569*^9, 3.641642850690707*^9}, {3.6417018015566783`*^9, 
   3.64170183063868*^9}, {3.6417023974582567`*^9, 3.641702398375893*^9}, {
   3.6417046932083406`*^9, 3.641704695697092*^9}, {3.641704822697073*^9, 
   3.6417048236887956`*^9}, {3.641705639264763*^9, 3.641705640846801*^9}, {
   3.6417059218313475`*^9, 3.641705921958435*^9}, {3.64170633725556*^9, 
   3.641706374253438*^9}, {3.6417067049278884`*^9, 3.641706760064662*^9}, {
   3.6417070085243587`*^9, 3.641707011792776*^9}, {3.641707072742837*^9, 
   3.6417071117596827`*^9}, {3.641707222541586*^9, 3.6417072365369234`*^9}, {
   3.641715354851606*^9, 3.6417153608929234`*^9}, {3.6424955548238134`*^9, 
   3.64249555725758*^9}, {3.642852811015979*^9, 3.642852812947257*^9}, {
   3.6429137631170454`*^9, 3.642913772479737*^9}, {3.642925636077099*^9, 
   3.642925638787101*^9}, {3.642934851536991*^9, 3.6429348560563602`*^9}, {
   3.6429377421714916`*^9, 3.6429377469549713`*^9}, {3.645164016564695*^9, 
   3.6451640206165977`*^9}, {3.6451744366431794`*^9, 3.6451744518141775`*^9}, 
   3.64517480367251*^9, {3.645249639759068*^9, 3.6452496398601046`*^9}, {
   3.6452515119553776`*^9, 3.6452515124306884`*^9}, {3.645252496569996*^9, 
   3.6452524967360964`*^9}, 3.6453374261274767`*^9, {3.6457891446307845`*^9, 
   3.645789146414056*^9}, {3.6457906864806066`*^9, 3.645790687942798*^9}, 
   3.64586132645926*^9, {3.6458626825791545`*^9, 3.6458626867959957`*^9}, {
   3.6459374849701834`*^9, 3.6459374853994446`*^9}, {3.6460245105627813`*^9, 
   3.6460245108650837`*^9}, {3.646038831763632*^9, 3.6460388534198127`*^9}, {
   3.6463709922959538`*^9, 3.646370992861314*^9}, 3.6473167310306983`*^9, {
   3.6476827597390227`*^9, 3.64768276437843*^9}, {3.648205858575919*^9, 
   3.6482058666082554`*^9}, {3.64820884568967*^9, 3.648208846316086*^9}, {
   3.6531964663346243`*^9, 3.6531964668449717`*^9}, {3.6536518535279236`*^9, 
   3.6536518609442196`*^9}, {3.6537378014019623`*^9, 
   3.6537378078976135`*^9}, {3.653797037087714*^9, 3.6537970404811306`*^9}, {
   3.653797280594222*^9, 3.6537972807343154`*^9}, {3.653815861957102*^9, 
   3.65381586636524*^9}, {3.654604842435624*^9, 3.654604850704508*^9}, 
   3.6557297561466837`*^9, 3.6579761697917185`*^9, {3.7110980999495926`*^9, 
   3.7110981032789345`*^9}, {3.7111018036325607`*^9, 
   3.7111018058621325`*^9}, {3.7111748789030876`*^9, 3.711174885005394*^9}, {
   3.7111860195243397`*^9, 3.7111860207322106`*^9}, {3.7111861499684806`*^9, 
   3.711186162533353*^9}, {3.7111863075607834`*^9, 3.711186319800433*^9}, {
   3.7112751604239655`*^9, 3.711275166727502*^9}, {3.711443323662431*^9, 
   3.7114433272940426`*^9}, {3.713073989254846*^9, 3.713073994038226*^9}, {
   3.7130819078681836`*^9, 3.7130819120201187`*^9}, {3.7130820960121713`*^9, 
   3.713082097330103*^9}, {3.7130868019124765`*^9, 3.7130868054079466`*^9}, 
   3.7130886421112037`*^9, {3.7320127929058685`*^9, 3.7320128135488343`*^9}, 
   3.732013182801684*^9, {3.7320132310292196`*^9, 3.732013282425955*^9}, {
   3.7320133637069635`*^9, 3.732013378691553*^9}, {3.7323357939131174`*^9, 
   3.732335800460183*^9}, {3.7323382503705893`*^9, 3.732338330176397*^9}, {
   3.732357994871482*^9, 3.7323580463852615`*^9}, {3.737953118232438*^9, 
   3.7379531214199486`*^9}, {3.737953753764694*^9, 3.7379537584990287`*^9}, {
   3.7379538338553452`*^9, 3.737953841608734*^9}, {3.7379583483590994`*^9, 
   3.737958351437334*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Migration rates for the three models", "Subsection",
 CellChangeTimes->{{3.732013240594036*^9, 3.7320132528460965`*^9}, {
  3.737953853871257*^9, 3.7379538830545406`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mNA12", "=", 
   RowBox[{"0.5", "*", "mMax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mNA21", "=", 
   RowBox[{"0.5", "*", "mMax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mPA12", "=", 
   RowBox[{"mMax", "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "c"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"y1", "[", "t", "]"}], "-", "b"}], ")"}]}], "]"}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mPA21", "=", 
   RowBox[{"mMax", "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "c"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"y2", "[", "t", "]"}], "-", "b"}], ")"}]}], "]"}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "=", 
   RowBox[{"0.5", "*", "maxY"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{"alpha", "/", "maxY"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mFD12", "=", 
   RowBox[{"mMax", "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Exp", "[", 
       RowBox[{"theta", "*", 
        RowBox[{"(", 
         RowBox[{"wx1", "-", "wx2"}], ")"}]}], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mFD21", "=", 
   RowBox[{"mMax", "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Exp", "[", 
       RowBox[{"theta", "*", 
        RowBox[{"(", 
         RowBox[{"wx2", "-", "wx1"}], ")"}]}], "]"}]}], ")"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.63384321232058*^9, 3.6338433693303194`*^9}, {
   3.6338434363900757`*^9, 3.6338435839454746`*^9}, {3.633843855171001*^9, 
   3.6338438893062057`*^9}, {3.6338439225998735`*^9, 
   3.6338439254738426`*^9}, {3.63384423383683*^9, 3.633844248011423*^9}, {
   3.633844381197025*^9, 3.633844382929221*^9}, {3.6338445033561444`*^9, 
   3.633844669069685*^9}, {3.6338447287076445`*^9, 3.633844795644618*^9}, {
   3.6338639053962603`*^9, 3.6338639661641936`*^9}, {3.6338644573253937`*^9, 
   3.633864457496523*^9}, {3.6338652128421335`*^9, 3.6338652553793373`*^9}, {
   3.6338653057188916`*^9, 3.633865317327881*^9}, {3.6338653598380623`*^9, 
   3.633865360071212*^9}, {3.633866820789173*^9, 3.633866921552353*^9}, {
   3.633866988560366*^9, 3.633867017960555*^9}, {3.63386708196548*^9, 
   3.633867148123923*^9}, {3.6338671983243923`*^9, 3.633867201069262*^9}, {
   3.6338678065952525`*^9, 3.633867810354806*^9}, 3.6338685288625336`*^9, {
   3.633868628004609*^9, 3.6338686368366556`*^9}, {3.6367855480930233`*^9, 
   3.6367855540379934`*^9}, {3.6376491541000304`*^9, 
   3.6376491656250772`*^9}, {3.637649664483103*^9, 3.637649671001433*^9}, {
   3.6376509645380573`*^9, 3.6376509668946733`*^9}, {3.6376512780099163`*^9, 
   3.6376513223298707`*^9}, {3.637651357659622*^9, 3.6376513603775377`*^9}, {
   3.6376514072075205`*^9, 3.6376514130496483`*^9}, {3.637651513220151*^9, 
   3.6376515175249753`*^9}, {3.6387040060553684`*^9, 3.638704013604545*^9}, {
   3.6387040936927943`*^9, 3.63870409992381*^9}, {3.6387047576350555`*^9, 
   3.6387047612495937`*^9}, {3.6388536263414373`*^9, 
   3.6388536424674225`*^9}, {3.6391128555126867`*^9, 
   3.6391128559259896`*^9}, {3.6391132293611097`*^9, 3.6391132299505396`*^9}, 
   3.6392000589998116`*^9, {3.639205572329553*^9, 3.639205576152357*^9}, {
   3.6392057404634466`*^9, 3.639205759184395*^9}, {3.63922000706166*^9, 
   3.639220035616212*^9}, {3.6393734393450537`*^9, 3.6393734406229815`*^9}, {
   3.6393754265427494`*^9, 3.6393754267979307`*^9}, 3.639383271151599*^9, {
   3.640083433268077*^9, 3.6400834409974127`*^9}, {3.6400835047282248`*^9, 
   3.6400835766456437`*^9}, {3.640084942127364*^9, 3.6400849491712065`*^9}, {
   3.640084998548346*^9, 3.640085043366728*^9}, {3.640085113864944*^9, 
   3.6400851496564064`*^9}, 3.640085250995848*^9, {3.6400852916629915`*^9, 
   3.6400853299140267`*^9}, {3.640085809654846*^9, 3.640085816309356*^9}, {
   3.6400858684328933`*^9, 3.640085887104669*^9}, {3.6400864882669773`*^9, 
   3.640086506143236*^9}, {3.640086543222749*^9, 3.640086543375832*^9}, {
   3.640086574775419*^9, 3.6400865749355507`*^9}, {3.6400868295465946`*^9, 
   3.640086829753707*^9}, {3.6403200960184793`*^9, 3.640320119258486*^9}, {
   3.640320153968317*^9, 3.640320211979248*^9}, {3.640320757793579*^9, 
   3.6403207973343525`*^9}, {3.6403208309917746`*^9, 3.640320858438243*^9}, {
   3.640321187793438*^9, 3.6403211893614855`*^9}, {3.640321303530441*^9, 
   3.640321340713526*^9}, 3.6403213755310163`*^9, {3.6403214202241683`*^9, 
   3.6403214203742685`*^9}, {3.640321502365585*^9, 3.640321515467422*^9}, {
   3.640321686143569*^9, 3.640321686245637*^9}, {3.640321885879883*^9, 
   3.640321888161436*^9}, {3.640321928557955*^9, 3.6403219533998766`*^9}, {
   3.6403221913109407`*^9, 3.640322193644531*^9}, {3.64032302990919*^9, 
   3.640323096635645*^9}, {3.640323135207919*^9, 3.6403231374944773`*^9}, {
   3.6403235087313633`*^9, 3.640323516464631*^9}, {3.640323784244042*^9, 
   3.6403237963753357`*^9}, {3.6406706945212193`*^9, 
   3.6406706947313585`*^9}, {3.640671529670863*^9, 3.640671553866048*^9}, {
   3.640676626200308*^9, 3.640676646556924*^9}, {3.640676838645421*^9, 
   3.6406768388005257`*^9}, {3.6412686918884706`*^9, 3.641268696801464*^9}, {
   3.641642768192569*^9, 3.641642850690707*^9}, {3.6417018015566783`*^9, 
   3.64170183063868*^9}, {3.6417023974582567`*^9, 3.641702398375893*^9}, {
   3.6417046932083406`*^9, 3.641704695697092*^9}, {3.641704822697073*^9, 
   3.6417048236887956`*^9}, {3.641705639264763*^9, 3.641705640846801*^9}, {
   3.6417059218313475`*^9, 3.641705921958435*^9}, {3.64170633725556*^9, 
   3.641706374253438*^9}, {3.6417067049278884`*^9, 3.641706760064662*^9}, {
   3.6417070085243587`*^9, 3.641707011792776*^9}, {3.641707072742837*^9, 
   3.6417071117596827`*^9}, {3.641707222541586*^9, 3.6417072365369234`*^9}, {
   3.641715354851606*^9, 3.6417153608929234`*^9}, {3.6424955548238134`*^9, 
   3.64249555725758*^9}, {3.642852811015979*^9, 3.642852812947257*^9}, {
   3.6429137631170454`*^9, 3.642913772479737*^9}, {3.642925636077099*^9, 
   3.642925638787101*^9}, {3.642934851536991*^9, 3.6429348560563602`*^9}, {
   3.6429377421714916`*^9, 3.6429377469549713`*^9}, {3.645164016564695*^9, 
   3.6451640206165977`*^9}, {3.6451744366431794`*^9, 3.6451744518141775`*^9}, 
   3.64517480367251*^9, {3.645249639759068*^9, 3.6452496398601046`*^9}, {
   3.6452515119553776`*^9, 3.6452515124306884`*^9}, {3.645252496569996*^9, 
   3.6452524967360964`*^9}, 3.6453374261274767`*^9, {3.6457891446307845`*^9, 
   3.645789146414056*^9}, {3.6457906864806066`*^9, 3.645790687942798*^9}, 
   3.64586132645926*^9, {3.6458626825791545`*^9, 3.6458626867959957`*^9}, {
   3.6459374849701834`*^9, 3.6459374853994446`*^9}, {3.6460245105627813`*^9, 
   3.6460245108650837`*^9}, {3.646038831763632*^9, 3.6460388534198127`*^9}, {
   3.6463709922959538`*^9, 3.646370992861314*^9}, 3.6473167310306983`*^9, {
   3.6476827597390227`*^9, 3.64768276437843*^9}, {3.648205858575919*^9, 
   3.6482058666082554`*^9}, {3.64820884568967*^9, 3.648208846316086*^9}, {
   3.6531964663346243`*^9, 3.6531964668449717`*^9}, {3.6536518535279236`*^9, 
   3.6536518609442196`*^9}, {3.6537378014019623`*^9, 
   3.6537378078976135`*^9}, {3.653797037087714*^9, 3.6537970404811306`*^9}, {
   3.653797280594222*^9, 3.6537972807343154`*^9}, {3.653815861957102*^9, 
   3.65381586636524*^9}, {3.654604842435624*^9, 3.654604850704508*^9}, 
   3.6557297561466837`*^9, 3.6579761697917185`*^9, {3.7110980999495926`*^9, 
   3.7110981032789345`*^9}, {3.7111018036325607`*^9, 
   3.7111018058621325`*^9}, {3.7111748789030876`*^9, 3.711174885005394*^9}, {
   3.7111860195243397`*^9, 3.7111860207322106`*^9}, {3.7111861499684806`*^9, 
   3.711186162533353*^9}, {3.7111863075607834`*^9, 3.711186319800433*^9}, {
   3.7112751604239655`*^9, 3.711275166727502*^9}, {3.711443323662431*^9, 
   3.7114433272940426`*^9}, {3.713073989254846*^9, 3.713073994038226*^9}, {
   3.7130819078681836`*^9, 3.7130819120201187`*^9}, {3.7130820960121713`*^9, 
   3.713082097330103*^9}, {3.7130868019124765`*^9, 3.7130868054079466`*^9}, 
   3.7130886421112037`*^9, {3.7320127929058685`*^9, 3.7320128135488343`*^9}, 
   3.732013182801684*^9, {3.7320132310292196`*^9, 3.732013282425955*^9}, {
   3.7320133637069635`*^9, 3.732013378691553*^9}, {3.7323357939131174`*^9, 
   3.732335800460183*^9}, {3.7323382503705893`*^9, 3.732338330176397*^9}, {
   3.732357994871482*^9, 3.7323580463852615`*^9}, {3.737953118232438*^9, 
   3.7379531214199486`*^9}, {3.737953753764694*^9, 3.7379537584990287`*^9}, {
   3.7379538338553452`*^9, 3.737953841608734*^9}, 3.737953887777827*^9, {
   3.7379577379414988`*^9, 3.7379577428380127`*^9}, {3.7379587408711967`*^9, 
   3.737958768012495*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Prey and predator equations", "Subsection",
 CellChangeTimes->{{3.732013240594036*^9, 3.7320132528460965`*^9}, {
  3.737953853871257*^9, 3.737953898741433*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dx1NonAdaptive", "=", 
   RowBox[{
    RowBox[{"wx1", "*", 
     RowBox[{"x1", "[", "t", "]"}]}], "-", 
    RowBox[{"mNA12", "*", 
     RowBox[{"x1", "[", "t", "]"}]}], "+", 
    RowBox[{"mNA21", "*", 
     RowBox[{"x2", "[", "t", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dx2NonAdaptive", "=", 
   RowBox[{
    RowBox[{"wx2", "*", 
     RowBox[{"x2", "[", "t", "]"}]}], "+", 
    RowBox[{"mNA12", "*", 
     RowBox[{"x1", "[", "t", "]"}]}], "-", 
    RowBox[{"mNA21", "*", 
     RowBox[{"x2", "[", "t", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dx1PredAvoidant", "=", 
   RowBox[{
    RowBox[{"wx1", "*", 
     RowBox[{"x1", "[", "t", "]"}]}], "-", 
    RowBox[{"mPA12", "*", 
     RowBox[{"x1", "[", "t", "]"}]}], "+", 
    RowBox[{"mPA21", "*", 
     RowBox[{"x2", "[", "t", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dx2PredAvoidant", "=", 
   RowBox[{
    RowBox[{"wx2", "*", 
     RowBox[{"x2", "[", "t", "]"}]}], "+", 
    RowBox[{"mPA12", "*", 
     RowBox[{"x1", "[", "t", "]"}]}], "-", 
    RowBox[{"mPA21", "*", 
     RowBox[{"x2", "[", "t", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dx1FitnessDependent", "=", 
   RowBox[{
    RowBox[{"wx1", "*", 
     RowBox[{"x1", "[", "t", "]"}]}], "-", 
    RowBox[{"mFD12", "*", 
     RowBox[{"x1", "[", "t", "]"}]}], "+", 
    RowBox[{"mFD21", "*", 
     RowBox[{"x2", "[", "t", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dx2FitnessDependent", "=", 
   RowBox[{
    RowBox[{"wx2", "*", 
     RowBox[{"x2", "[", "t", "]"}]}], "+", 
    RowBox[{"mFD12", "*", 
     RowBox[{"x1", "[", "t", "]"}]}], "-", 
    RowBox[{"mFD21", "*", 
     RowBox[{"x2", "[", "t", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dy1", "=", 
   RowBox[{"wy1", "*", 
    RowBox[{"y1", "[", "t", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dy2", "=", 
   RowBox[{"wy2", "*", 
    RowBox[{"y2", "[", "t", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.63384321232058*^9, 3.6338433693303194`*^9}, {
   3.6338434363900757`*^9, 3.6338435839454746`*^9}, {3.633843855171001*^9, 
   3.6338438893062057`*^9}, {3.6338439225998735`*^9, 
   3.6338439254738426`*^9}, {3.63384423383683*^9, 3.633844248011423*^9}, {
   3.633844381197025*^9, 3.633844382929221*^9}, {3.6338445033561444`*^9, 
   3.633844669069685*^9}, {3.6338447287076445`*^9, 3.633844795644618*^9}, {
   3.6338639053962603`*^9, 3.6338639661641936`*^9}, {3.6338644573253937`*^9, 
   3.633864457496523*^9}, {3.6338652128421335`*^9, 3.6338652553793373`*^9}, {
   3.6338653057188916`*^9, 3.633865317327881*^9}, {3.6338653598380623`*^9, 
   3.633865360071212*^9}, {3.633866820789173*^9, 3.633866921552353*^9}, {
   3.633866988560366*^9, 3.633867017960555*^9}, {3.63386708196548*^9, 
   3.633867148123923*^9}, {3.6338671983243923`*^9, 3.633867201069262*^9}, {
   3.6338678065952525`*^9, 3.633867810354806*^9}, 3.6338685288625336`*^9, {
   3.633868628004609*^9, 3.6338686368366556`*^9}, {3.6367855480930233`*^9, 
   3.6367855540379934`*^9}, {3.6376491541000304`*^9, 
   3.6376491656250772`*^9}, {3.637649664483103*^9, 3.637649671001433*^9}, {
   3.6376509645380573`*^9, 3.6376509668946733`*^9}, {3.6376512780099163`*^9, 
   3.6376513223298707`*^9}, {3.637651357659622*^9, 3.6376513603775377`*^9}, {
   3.6376514072075205`*^9, 3.6376514130496483`*^9}, {3.637651513220151*^9, 
   3.6376515175249753`*^9}, {3.6387040060553684`*^9, 3.638704013604545*^9}, {
   3.6387040936927943`*^9, 3.63870409992381*^9}, {3.6387047576350555`*^9, 
   3.6387047612495937`*^9}, {3.6388536263414373`*^9, 
   3.6388536424674225`*^9}, {3.6391128555126867`*^9, 
   3.6391128559259896`*^9}, {3.6391132293611097`*^9, 3.6391132299505396`*^9}, 
   3.6392000589998116`*^9, {3.639205572329553*^9, 3.639205576152357*^9}, {
   3.6392057404634466`*^9, 3.639205759184395*^9}, {3.63922000706166*^9, 
   3.639220035616212*^9}, {3.6393734393450537`*^9, 3.6393734406229815`*^9}, {
   3.6393754265427494`*^9, 3.6393754267979307`*^9}, 3.639383271151599*^9, {
   3.640083433268077*^9, 3.6400834409974127`*^9}, {3.6400835047282248`*^9, 
   3.6400835766456437`*^9}, {3.640084942127364*^9, 3.6400849491712065`*^9}, {
   3.640084998548346*^9, 3.640085043366728*^9}, {3.640085113864944*^9, 
   3.6400851496564064`*^9}, 3.640085250995848*^9, {3.6400852916629915`*^9, 
   3.6400853299140267`*^9}, {3.640085809654846*^9, 3.640085816309356*^9}, {
   3.6400858684328933`*^9, 3.640085887104669*^9}, {3.6400864882669773`*^9, 
   3.640086506143236*^9}, {3.640086543222749*^9, 3.640086543375832*^9}, {
   3.640086574775419*^9, 3.6400865749355507`*^9}, {3.6400868295465946`*^9, 
   3.640086829753707*^9}, {3.6403200960184793`*^9, 3.640320119258486*^9}, {
   3.640320153968317*^9, 3.640320211979248*^9}, {3.640320757793579*^9, 
   3.6403207973343525`*^9}, {3.6403208309917746`*^9, 3.640320858438243*^9}, {
   3.640321187793438*^9, 3.6403211893614855`*^9}, {3.640321303530441*^9, 
   3.640321340713526*^9}, 3.6403213755310163`*^9, {3.6403214202241683`*^9, 
   3.6403214203742685`*^9}, {3.640321502365585*^9, 3.640321515467422*^9}, {
   3.640321686143569*^9, 3.640321686245637*^9}, {3.640321885879883*^9, 
   3.640321888161436*^9}, {3.640321928557955*^9, 3.6403219533998766`*^9}, {
   3.6403221913109407`*^9, 3.640322193644531*^9}, {3.64032302990919*^9, 
   3.640323096635645*^9}, {3.640323135207919*^9, 3.6403231374944773`*^9}, {
   3.6403235087313633`*^9, 3.640323516464631*^9}, {3.640323784244042*^9, 
   3.6403237963753357`*^9}, {3.6406706945212193`*^9, 
   3.6406706947313585`*^9}, {3.640671529670863*^9, 3.640671553866048*^9}, {
   3.640676626200308*^9, 3.640676646556924*^9}, {3.640676838645421*^9, 
   3.6406768388005257`*^9}, {3.6412686918884706`*^9, 3.641268696801464*^9}, {
   3.641642768192569*^9, 3.641642850690707*^9}, {3.6417018015566783`*^9, 
   3.64170183063868*^9}, {3.6417023974582567`*^9, 3.641702398375893*^9}, {
   3.6417046932083406`*^9, 3.641704695697092*^9}, {3.641704822697073*^9, 
   3.6417048236887956`*^9}, {3.641705639264763*^9, 3.641705640846801*^9}, {
   3.6417059218313475`*^9, 3.641705921958435*^9}, {3.64170633725556*^9, 
   3.641706374253438*^9}, {3.6417067049278884`*^9, 3.641706760064662*^9}, {
   3.6417070085243587`*^9, 3.641707011792776*^9}, {3.641707072742837*^9, 
   3.6417071117596827`*^9}, {3.641707222541586*^9, 3.6417072365369234`*^9}, {
   3.641715354851606*^9, 3.6417153608929234`*^9}, {3.6424955548238134`*^9, 
   3.64249555725758*^9}, {3.642852811015979*^9, 3.642852812947257*^9}, {
   3.6429137631170454`*^9, 3.642913772479737*^9}, {3.642925636077099*^9, 
   3.642925638787101*^9}, {3.642934851536991*^9, 3.6429348560563602`*^9}, {
   3.6429377421714916`*^9, 3.6429377469549713`*^9}, {3.645164016564695*^9, 
   3.6451640206165977`*^9}, {3.6451744366431794`*^9, 3.6451744518141775`*^9}, 
   3.64517480367251*^9, {3.645249639759068*^9, 3.6452496398601046`*^9}, {
   3.6452515119553776`*^9, 3.6452515124306884`*^9}, {3.645252496569996*^9, 
   3.6452524967360964`*^9}, 3.6453374261274767`*^9, {3.6457891446307845`*^9, 
   3.645789146414056*^9}, {3.6457906864806066`*^9, 3.645790687942798*^9}, 
   3.64586132645926*^9, {3.6458626825791545`*^9, 3.6458626867959957`*^9}, {
   3.6459374849701834`*^9, 3.6459374853994446`*^9}, {3.6460245105627813`*^9, 
   3.6460245108650837`*^9}, {3.646038831763632*^9, 3.6460388534198127`*^9}, {
   3.6463709922959538`*^9, 3.646370992861314*^9}, 3.6473167310306983`*^9, {
   3.6476827597390227`*^9, 3.64768276437843*^9}, {3.648205858575919*^9, 
   3.6482058666082554`*^9}, {3.64820884568967*^9, 3.648208846316086*^9}, {
   3.6531964663346243`*^9, 3.6531964668449717`*^9}, {3.6536518535279236`*^9, 
   3.6536518609442196`*^9}, {3.6537378014019623`*^9, 
   3.6537378078976135`*^9}, {3.653797037087714*^9, 3.6537970404811306`*^9}, {
   3.653797280594222*^9, 3.6537972807343154`*^9}, {3.653815861957102*^9, 
   3.65381586636524*^9}, {3.654604842435624*^9, 3.654604850704508*^9}, 
   3.6557297561466837`*^9, 3.6579761697917185`*^9, {3.7110980999495926`*^9, 
   3.7110981032789345`*^9}, {3.7111018036325607`*^9, 
   3.7111018058621325`*^9}, {3.7111748789030876`*^9, 3.711174885005394*^9}, {
   3.7111860195243397`*^9, 3.7111860207322106`*^9}, {3.7111861499684806`*^9, 
   3.711186162533353*^9}, {3.7111863075607834`*^9, 3.711186319800433*^9}, {
   3.7112751604239655`*^9, 3.711275166727502*^9}, {3.711443323662431*^9, 
   3.7114433272940426`*^9}, {3.713073989254846*^9, 3.713073994038226*^9}, {
   3.7130819078681836`*^9, 3.7130819120201187`*^9}, {3.7130820960121713`*^9, 
   3.713082097330103*^9}, {3.7130868019124765`*^9, 3.7130868054079466`*^9}, 
   3.7130886421112037`*^9, {3.7320127929058685`*^9, 3.7320128135488343`*^9}, 
   3.732013182801684*^9, {3.7320132310292196`*^9, 3.732013282425955*^9}, {
   3.7320133637069635`*^9, 3.732013378691553*^9}, {3.7323357939131174`*^9, 
   3.732335800460183*^9}, {3.7323382503705893`*^9, 3.732338330176397*^9}, {
   3.732357994871482*^9, 3.7323580463852615`*^9}, {3.737953118232438*^9, 
   3.7379531214199486`*^9}, {3.737953753764694*^9, 3.7379537584990287`*^9}, {
   3.7379538338553452`*^9, 3.737953841608734*^9}, {3.737953887777827*^9, 
   3.737953906017555*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Defining the initial conditions and system of differential equations\
\>", "Subsection",
 CellChangeTimes->{{3.732013268222595*^9, 3.7320132808477526`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"InitialConditions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"x1", "[", "0", "]"}], "\[Equal]", "0.5"}], ",", 
     RowBox[{
      RowBox[{"x2", "[", "0", "]"}], "\[Equal]", "0.55"}], ",", 
     RowBox[{
      RowBox[{"y1", "[", "0", "]"}], "\[Equal]", "0.2"}], ",", 
     RowBox[{
      RowBox[{"y2", "[", "0", "]"}], "\[Equal]", "0.1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SysNonAdaptive", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x1", "'"}], "[", "t", "]"}], "\[Equal]", "dx1NonAdaptive"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x2", "'"}], "[", "t", "]"}], "\[Equal]", "dx2NonAdaptive"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"y1", "'"}], "[", "t", "]"}], "\[Equal]", "dy1"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"y2", "'"}], "[", "t", "]"}], "\[Equal]", "dy2"}], ",", 
     "InitialConditions"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SysPredAvoidant", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x1", "'"}], "[", "t", "]"}], "\[Equal]", "dx1PredAvoidant"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x2", "'"}], "[", "t", "]"}], "\[Equal]", "dx2PredAvoidant"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"y1", "'"}], "[", "t", "]"}], "\[Equal]", "dy1"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"y2", "'"}], "[", "t", "]"}], "\[Equal]", "dy2"}], ",", 
     "InitialConditions"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SysFitnessDependent", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x1", "'"}], "[", "t", "]"}], "\[Equal]", 
      "dx1FitnessDependent"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x2", "'"}], "[", "t", "]"}], "\[Equal]", 
      "dx2FitnessDependent"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"y1", "'"}], "[", "t", "]"}], "\[Equal]", "dy1"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"y2", "'"}], "[", "t", "]"}], "\[Equal]", "dy2"}], ",", 
     "InitialConditions"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7323358054134803`*^9, 3.7323358146028175`*^9}, {
   3.7323580509455123`*^9, 3.732358065574954*^9}, 3.7379539149771557`*^9, 
   3.7379579105211143`*^9, {3.737958354984337*^9, 3.737958357000005*^9}, 
   3.7379584483313837`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulations", "Section",
 CellChangeTimes->{{3.7320133110419044`*^9, 3.7320133161357374`*^9}}],

Cell[CellGroupData[{

Cell["Model 1: non-adaptive exchange", "Subsection",
 CellChangeTimes->{{3.732335947091011*^9, 3.7323359483410482`*^9}, {
  3.73233602594783*^9, 3.732336026260391*^9}, {3.737958413314539*^9, 
  3.7379584165958652`*^9}}],

Cell[CellGroupData[{

Cell["Defining parameter values and global simulation parameters", \
"Subsubsection",
 CellChangeTimes->{{3.7323360232584224`*^9, 3.73233603410437*^9}, {
  3.732336120509369*^9, 3.732336128370386*^9}, {3.7323362192289944`*^9, 
  3.7323362309026337`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"params", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", "\[Rule]", "0.1"}], ",", 
     RowBox[{"e1", "\[Rule]", "0.33"}], ",", 
     RowBox[{"e2", "\[Rule]", "0.33"}], ",", 
     RowBox[{"r1", "\[Rule]", "0.5"}], ",", 
     RowBox[{"r2", "\[Rule]", "0.5"}], ",", 
     RowBox[{"a1", "\[Rule]", "5"}], ",", 
     RowBox[{"a2", "\[Rule]", "5"}], ",", 
     RowBox[{"h1", "\[Rule]", "1"}], ",", 
     RowBox[{"h2", "\[Rule]", "1"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sys1", "=", 
   RowBox[{"SysNonAdaptive", "/.", "params"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", "50000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numsteps", "=", "20000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numvaluesM", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numvaluesK", "=", "21"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"minK", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxK", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"minM", "=", 
   RowBox[{"-", "3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxM", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7320133188232527`*^9, 3.7320133188232527`*^9}, {
   3.7320134089947767`*^9, 3.732013411791725*^9}, {3.732013473584118*^9, 
   3.7320135000263968`*^9}, {3.7323356355200157`*^9, 
   3.7323356552397146`*^9}, {3.732335688914898*^9, 3.7323356904149694`*^9}, 
   3.7323359352763615`*^9, 3.732335974454573*^9, {3.7323360454033327`*^9, 
   3.7323361687049174`*^9}, {3.7323362463717318`*^9, 3.7323362465279427`*^9}, 
   3.7323377955414143`*^9, {3.732337840061029*^9, 3.732337840592286*^9}, {
   3.732337971581377*^9, 3.7323379789095926`*^9}, {3.7323382627947397`*^9, 
   3.732338279125016*^9}, 3.7323384821748285`*^9, 3.732338671949501*^9, 
   3.7323391185066075`*^9, 3.732339442938012*^9, {3.7379539999194174`*^9, 
   3.7379541208356905`*^9}, {3.737957697517645*^9, 3.7379577192111263`*^9}, {
   3.7379579387247047`*^9, 3.7379579433654065`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Arrays for storing simulated time series", "Subsubsection",
 CellChangeTimes->{{3.732336310051952*^9, 3.732336317631905*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"x1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xvalues", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"yvalues", "=", 
    RowBox[{"Array", "[", 
     RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"timeseries", " ", "on", " ", "log", " ", "scale"}], ",", " ", 
    RowBox[{
    "and", " ", "differences", " ", "between", " ", "two", " ", 
     "timepoints"}], ",", " ", 
    RowBox[{
    "for", " ", "calculation", " ", "of", " ", "correlation", " ", 
     "coefficients"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logx1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logx2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logy1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logy2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diffx1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diffx2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diffy1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diffy2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.7323363287571*^9, {3.7323363598244133`*^9, 3.7323364063004847`*^9}, 
   3.7323383484753594`*^9, {3.7379541232149906`*^9, 3.737954135431669*^9}, {
   3.737954184867968*^9, 3.737954191156988*^9}, 3.73795686899143*^9, {
   3.737957031270731*^9, 3.7379570418555694`*^9}, {3.7379572141234903`*^9, 
   3.737957235668403*^9}, {3.73795746662475*^9, 3.737957502154558*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining arrays of output values", "Subsubsection",
 CellChangeTimes->{{3.732336203242155*^9, 3.7323362160101323`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"meanprey", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"meanpred", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"stdevprey", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"stdevpred", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cvprey", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cvpred", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"correlationprey", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"correlationpred", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7323362429184756`*^9, 3.732336321803821*^9}, {
   3.732336423069455*^9, 3.7323365046889153`*^9}, {3.7323367871968145`*^9, 
   3.732336791276896*^9}, {3.732337510433137*^9, 3.7323375538140297`*^9}, {
   3.7323379080885763`*^9, 3.7323379357493243`*^9}, {3.7323383507097507`*^9, 
   3.7323383518816357`*^9}, 3.737954417604087*^9, {3.737954596407192*^9, 
   3.7379546652891273`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Simulation on a grid of parameter values for migration rate and carrying \
capacity\
\>", "Subsubsection",
 CellChangeTimes->{{3.732336529925578*^9, 3.732336550414056*^9}, {
  3.7379542038248253`*^9, 3.737954225297949*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "\[LessEqual]", 
     RowBox[{"numvaluesM", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "\[LessEqual]", 
       RowBox[{"numvaluesK", "+", "1"}]}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
        "substituting", " ", "values", " ", "for", " ", "mMax", " ", "and", 
         " ", "k"}], ",", " ", 
        RowBox[{
        "and", " ", "numerical", " ", "solving", " ", "of", " ", "the", " ", 
         "differential", " ", "equations"}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"z1", "=", 
        RowBox[{"minM", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"i", "-", "1"}], ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"maxM", "-", "minM"}], ")"}], "/", "numvaluesM"}]}]}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"z2", "=", 
        RowBox[{"minK", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"j", "-", "1"}], ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"maxK", "-", "minK"}], ")"}], "/", "numvaluesK"}]}]}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Sys2", "=", 
        RowBox[{"Sys1", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"mMax", "\[Rule]", 
            RowBox[{"10", "^", "z1"}]}], ",", 
           RowBox[{"k", "\[Rule]", "z2"}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"sol1", "=", 
        RowBox[{"NDSolve", "[", 
         RowBox[{"Sys2", ",", 
          RowBox[{"{", 
           RowBox[{"x1", ",", "x2", ",", "y1", ",", "y2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
          RowBox[{"PrecisionGoal", "\[Rule]", "13"}], ",", 
          RowBox[{"AccuracyGoal", "\[Rule]", "13"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"generating", " ", "timeseries"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"m", "=", "1"}], ",", 
         RowBox[{"m", "\[LessEqual]", 
          RowBox[{"numsteps", "+", "1"}]}], ",", 
         RowBox[{"m", "++"}], ",", 
         RowBox[{
          RowBox[{"n", "=", 
           RowBox[{"tmax", "-", "numsteps", "-", "1", "+", "m"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"x1", "[", "n", "]"}], "/.", "sol1"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"x2", "[", "n", "]"}], "/.", "sol1"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"xvalues", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"x1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "+", 
            RowBox[{"x2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"y1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"y1", "[", "n", "]"}], "/.", "sol1"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"y2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"y2", "[", "n", "]"}], "/.", "sol1"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"yvalues", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"y1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "+", 
            RowBox[{"y2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"logx1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{"Log10", "[", 
            RowBox[{"x1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"logx2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{"Log10", "[", 
            RowBox[{"x2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"logy1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{"Log10", "[", 
            RowBox[{"y1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"logy2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{"Log10", "[", 
            RowBox[{"y2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "]"}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"calculating", " ", "means"}], ",", " ", 
         RowBox[{"standard", " ", "deviations"}], ",", " ", 
         RowBox[{"and", " ", "coefficient", " ", "of", " ", "variation"}]}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"meanprey", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"Mean", "[", "xvalues", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"meanpred", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"Mean", "[", "yvalues", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"stdevprey", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"StandardDeviation", "[", "xvalues", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"stdevpred", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"StandardDeviation", "[", "yvalues", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cvprey", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"stdevprey", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], "/", 
         RowBox[{"meanprey", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cvpred", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"stdevpred", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], "/", 
         RowBox[{"meanpred", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "generate", " ", "difference", " ", "of", " ", "log", " ", "of", " ",
           "timeseries"}], ",", " ", 
         RowBox[{"for", " ", "calculation", " ", "of", " ", "correlation"}]}],
         "*)"}], "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"m", "=", "1"}], ",", 
         RowBox[{"m", "\[LessEqual]", "numsteps"}], ",", 
         RowBox[{"m", "++"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"diffx1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"logx1values", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"logx1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"diffx2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"logx2values", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"logx2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"diffy1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"logy1values", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"logy1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"diffy2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"logy2values", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"logy2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "calculation", " ", "of", " ", "correlation", " ", "coefficients", 
         " ", "for", " ", "prey", " ", "and", " ", "predator", " ", 
         "dynamics"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"correlationprey", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"Correlation", "[", 
         RowBox[{"diffx1values", ",", "diffx2values"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"correlationpred", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"Correlation", "[", 
         RowBox[{"diffy1values", ",", "diffy2values"}], "]"}]}], ";"}]}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "end", " ", "of", " ", "calculations", " ", "for", " ", "a", " ", 
        "single", " ", "simulation", " ", "run"}], ";", " ", 
       RowBox[{
       "return", " ", "to", " ", "the", " ", "next", " ", "iteration", " ", 
        "of", " ", "the", " ", "loop"}]}], "*)"}], "\[IndentingNewLine]", 
     "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.732336569433798*^9, 3.7323366852963533`*^9}, {
   3.7323367387850437`*^9, 3.7323369982084084`*^9}, {3.7323370286974297`*^9, 
   3.7323370394163523`*^9}, {3.732337092627457*^9, 3.7323371893742886`*^9}, {
   3.732337228409675*^9, 3.7323375071049304`*^9}, {3.7323375637845488`*^9, 
   3.7323377653169785`*^9}, {3.7323378445473537`*^9, 3.732337851406842*^9}, {
   3.7323380295549593`*^9, 3.7323380529640846`*^9}, {3.7323383607099037`*^9, 
   3.7323384162473373`*^9}, {3.7323385480137167`*^9, 3.732338548607476*^9}, {
   3.732338730457673*^9, 3.732338732332697*^9}, {3.7323388456466856`*^9, 
   3.732338852365546*^9}, {3.7379567773638945`*^9, 3.7379568081300282`*^9}, {
   3.7379568404050207`*^9, 3.737957128577719*^9}, {3.7379572405560355`*^9, 
   3.7379573991467075`*^9}, {3.7379574311509805`*^9, 
   3.7379574412563295`*^9}, {3.7379575091947007`*^9, 
   3.7379576202624826`*^9}, {3.7379577506325684`*^9, 3.7379577532684298`*^9}, 
   3.737957786409658*^9, {3.737957835316716*^9, 3.737957842160579*^9}, {
   3.7379579545842924`*^9, 3.7379579826629024`*^9}, {3.7379580199304314`*^9, 
   3.7379580200241632`*^9}, {3.7379588785462284`*^9, 3.737958883827609*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model 2: predator-avoidant exchange", "Subsection",
 CellChangeTimes->{{3.732335947091011*^9, 3.7323359483410482`*^9}, {
  3.73233602594783*^9, 3.732336026260391*^9}, {3.737958413314539*^9, 
  3.7379584165958652`*^9}, {3.737958580820479*^9, 3.7379585858050137`*^9}}],

Cell[CellGroupData[{

Cell["Defining parameter values and global simulation parameters\
\[AliasDelimiter]", "Subsubsection",
 CellChangeTimes->{{3.7323360232584224`*^9, 3.73233603410437*^9}, {
   3.732336120509369*^9, 3.732336128370386*^9}, {3.7323362192289944`*^9, 
   3.7323362309026337`*^9}, 3.737960137260043*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"params", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", "\[Rule]", "0.1"}], ",", 
     RowBox[{"e1", "\[Rule]", "0.33"}], ",", 
     RowBox[{"e2", "\[Rule]", "0.33"}], ",", 
     RowBox[{"r1", "\[Rule]", "0.5"}], ",", 
     RowBox[{"r2", "\[Rule]", "0.5"}], ",", 
     RowBox[{"a1", "\[Rule]", "5"}], ",", 
     RowBox[{"a2", "\[Rule]", "5"}], ",", 
     RowBox[{"h1", "\[Rule]", "1"}], ",", 
     RowBox[{"h2", "\[Rule]", "1"}], ",", 
     RowBox[{"alpha", "\[Rule]", "10"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sys1", "=", 
   RowBox[{"SysPredAvoidant", "/.", "params"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", "50000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numsteps", "=", "20000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numvaluesM", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numvaluesK", "=", "21"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"minK", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxK", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"minM", "=", 
   RowBox[{"-", "3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxM", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxvaluesKmin1Kmax4", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.420199", ",", "0.480166", ",", "0.540047", ",", "0.599862", ",", 
     "0.659576", ",", "0.719395", ",", "0.77918", ",", "0.83896", ",", 
     "0.898745", ",", "0.950846", ",", "1.01839", ",", "1.07827", ",", 
     "1.13815", ",", "1.19806", ",", "1.25767", ",", "1.31818", ",", 
     "1.37824", ",", "1.43842", ",", "1.49857", ",", "1.55879", ",", 
     "1.61914", ",", "1.67947"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7320133188232527`*^9, 3.7320133188232527`*^9}, {
   3.7320134089947767`*^9, 3.732013411791725*^9}, {3.732013473584118*^9, 
   3.7320135000263968`*^9}, {3.7323356355200157`*^9, 
   3.7323356552397146`*^9}, {3.732335688914898*^9, 3.7323356904149694`*^9}, 
   3.7323359352763615`*^9, 3.732335974454573*^9, {3.7323360454033327`*^9, 
   3.7323361687049174`*^9}, {3.7323362463717318`*^9, 3.7323362465279427`*^9}, 
   3.7323377955414143`*^9, {3.732337840061029*^9, 3.732337840592286*^9}, {
   3.732337971581377*^9, 3.7323379789095926`*^9}, {3.7323382627947397`*^9, 
   3.732338279125016*^9}, 3.7323384821748285`*^9, 3.732338671949501*^9, 
   3.7323391185066075`*^9, 3.732339442938012*^9, {3.7379539999194174`*^9, 
   3.7379541208356905`*^9}, {3.737957697517645*^9, 3.7379577192111263`*^9}, {
   3.7379579387247047`*^9, 3.7379579433654065`*^9}, {3.737958591180196*^9, 
   3.7379586528223667`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Arrays for storing simulated time series", "Subsubsection",
 CellChangeTimes->{{3.732336310051952*^9, 3.732336317631905*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"x1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xvalues", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"yvalues", "=", 
    RowBox[{"Array", "[", 
     RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"timeseries", " ", "on", " ", "log", " ", "scale"}], ",", " ", 
    RowBox[{
    "and", " ", "differences", " ", "between", " ", "two", " ", 
     "timepoints"}], ",", " ", 
    RowBox[{
    "for", " ", "calculation", " ", "of", " ", "correlation", " ", 
     "coefficients"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logx1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logx2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logy1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logy2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diffx1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diffx2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diffy1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diffy2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.7323363287571*^9, {3.7323363598244133`*^9, 3.7323364063004847`*^9}, 
   3.7323383484753594`*^9, {3.7379541232149906`*^9, 3.737954135431669*^9}, {
   3.737954184867968*^9, 3.737954191156988*^9}, 3.73795686899143*^9, {
   3.737957031270731*^9, 3.7379570418555694`*^9}, {3.7379572141234903`*^9, 
   3.737957235668403*^9}, {3.73795746662475*^9, 3.737957502154558*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining arrays of output values", "Subsubsection",
 CellChangeTimes->{{3.732336203242155*^9, 3.7323362160101323`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"meanprey", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"meanpred", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"stdevprey", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"stdevpred", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cvprey", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cvpred", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"correlationprey", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"correlationpred", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7323362429184756`*^9, 3.732336321803821*^9}, {
   3.732336423069455*^9, 3.7323365046889153`*^9}, {3.7323367871968145`*^9, 
   3.732336791276896*^9}, {3.732337510433137*^9, 3.7323375538140297`*^9}, {
   3.7323379080885763`*^9, 3.7323379357493243`*^9}, {3.7323383507097507`*^9, 
   3.7323383518816357`*^9}, 3.737954417604087*^9, {3.737954596407192*^9, 
   3.7379546652891273`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Simulation on a grid of parameter values for migration rate and carrying \
capacity\
\>", "Subsubsection",
 CellChangeTimes->{{3.732336529925578*^9, 3.732336550414056*^9}, {
  3.7379542038248253`*^9, 3.737954225297949*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "\[LessEqual]", 
     RowBox[{"numvaluesM", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "\[LessEqual]", 
       RowBox[{"numvaluesK", "+", "1"}]}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"substituting", " ", "values", " ", "for", " ", "mMax"}], ",",
         " ", "k", ",", " ", 
        RowBox[{"and", " ", "maxY"}], ",", " ", 
        RowBox[{
        "and", " ", "numerical", " ", "solving", " ", "of", " ", "the", " ", 
         "differential", " ", "equations"}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"z1", "=", 
        RowBox[{"minM", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"i", "-", "1"}], ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"maxM", "-", "minM"}], ")"}], "/", "numvaluesM"}]}]}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"z2", "=", 
        RowBox[{"minK", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"j", "-", "1"}], ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"maxK", "-", "minK"}], ")"}], "/", "numvaluesK"}]}]}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"z3", "=", 
        RowBox[{"maxvaluesKmin1Kmax4", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Sys2", "=", 
        RowBox[{"Sys1", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"mMax", "\[Rule]", 
            RowBox[{"10", "^", "z1"}]}], ",", 
           RowBox[{"k", "\[Rule]", "z2"}], ",", 
           RowBox[{"maxY", "\[Rule]", "z3"}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"sol1", "=", 
        RowBox[{"NDSolve", "[", 
         RowBox[{"Sys2", ",", 
          RowBox[{"{", 
           RowBox[{"x1", ",", "x2", ",", "y1", ",", "y2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
          RowBox[{"PrecisionGoal", "\[Rule]", "13"}], ",", 
          RowBox[{"AccuracyGoal", "\[Rule]", "13"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"generating", " ", "timeseries"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"m", "=", "1"}], ",", 
         RowBox[{"m", "\[LessEqual]", 
          RowBox[{"numsteps", "+", "1"}]}], ",", 
         RowBox[{"m", "++"}], ",", 
         RowBox[{
          RowBox[{"n", "=", 
           RowBox[{"tmax", "-", "numsteps", "-", "1", "+", "m"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"x1", "[", "n", "]"}], "/.", "sol1"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"x2", "[", "n", "]"}], "/.", "sol1"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"xvalues", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"x1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "+", 
            RowBox[{"x2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"y1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"y1", "[", "n", "]"}], "/.", "sol1"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"y2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"y2", "[", "n", "]"}], "/.", "sol1"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"yvalues", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"y1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "+", 
            RowBox[{"y2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"logx1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{"Log10", "[", 
            RowBox[{"x1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"logx2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{"Log10", "[", 
            RowBox[{"x2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"logy1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{"Log10", "[", 
            RowBox[{"y1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"logy2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{"Log10", "[", 
            RowBox[{"y2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "]"}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"calculating", " ", "means"}], ",", " ", 
         RowBox[{"standard", " ", "deviations"}], ",", " ", 
         RowBox[{"and", " ", "coefficient", " ", "of", " ", "variation"}]}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"meanprey", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"Mean", "[", "xvalues", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"meanpred", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"Mean", "[", "yvalues", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"stdevprey", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"StandardDeviation", "[", "xvalues", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"stdevpred", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"StandardDeviation", "[", "yvalues", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cvprey", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"stdevprey", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], "/", 
         RowBox[{"meanprey", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cvpred", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"stdevpred", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], "/", 
         RowBox[{"meanpred", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "generate", " ", "difference", " ", "of", " ", "log", " ", "of", " ",
           "timeseries"}], ",", " ", 
         RowBox[{"for", " ", "calculation", " ", "of", " ", "correlation"}]}],
         "*)"}], "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"m", "=", "1"}], ",", 
         RowBox[{"m", "\[LessEqual]", "numsteps"}], ",", 
         RowBox[{"m", "++"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"diffx1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"logx1values", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"logx1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"diffx2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"logx2values", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"logx2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"diffy1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"logy1values", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"logy1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"diffy2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"logy2values", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"logy2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "calculation", " ", "of", " ", "correlation", " ", "coefficients", 
         " ", "for", " ", "prey", " ", "and", " ", "predator", " ", 
         "dynamics"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"correlationprey", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"Correlation", "[", 
         RowBox[{"diffx1values", ",", "diffx2values"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"correlationpred", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"Correlation", "[", 
         RowBox[{"diffy1values", ",", "diffy2values"}], "]"}]}], ";"}]}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "end", " ", "of", " ", "calculations", " ", "for", " ", "a", " ", 
        "single", " ", "simulation", " ", "run"}], ";", " ", 
       RowBox[{
       "return", " ", "to", " ", "the", " ", "next", " ", "iteration", " ", 
        "of", " ", "the", " ", "loop"}]}], "*)"}], "\[IndentingNewLine]", 
     "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.732336569433798*^9, 3.7323366852963533`*^9}, {
   3.7323367387850437`*^9, 3.7323369982084084`*^9}, {3.7323370286974297`*^9, 
   3.7323370394163523`*^9}, {3.732337092627457*^9, 3.7323371893742886`*^9}, {
   3.732337228409675*^9, 3.7323375071049304`*^9}, {3.7323375637845488`*^9, 
   3.7323377653169785`*^9}, {3.7323378445473537`*^9, 3.732337851406842*^9}, {
   3.7323380295549593`*^9, 3.7323380529640846`*^9}, {3.7323383607099037`*^9, 
   3.7323384162473373`*^9}, {3.7323385480137167`*^9, 3.732338548607476*^9}, {
   3.732338730457673*^9, 3.732338732332697*^9}, {3.7323388456466856`*^9, 
   3.732338852365546*^9}, {3.7379567773638945`*^9, 3.7379568081300282`*^9}, {
   3.7379568404050207`*^9, 3.737957128577719*^9}, {3.7379572405560355`*^9, 
   3.7379573991467075`*^9}, {3.7379574311509805`*^9, 
   3.7379574412563295`*^9}, {3.7379575091947007`*^9, 
   3.7379576202624826`*^9}, {3.7379577506325684`*^9, 3.7379577532684298`*^9}, 
   3.737957786409658*^9, {3.737957835316716*^9, 3.737957842160579*^9}, {
   3.7379579545842924`*^9, 3.7379579826629024`*^9}, {3.7379580199304314`*^9, 
   3.7379580200241632`*^9}, {3.737958673791596*^9, 3.737958715026883*^9}, {
   3.7379587916067314`*^9, 3.7379587993881817`*^9}, {3.7379588563113546`*^9, 
   3.737958868702263*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model 3: fitness-dependent exchange", "Subsection",
 CellChangeTimes->{{3.732335947091011*^9, 3.7323359483410482`*^9}, {
  3.73233602594783*^9, 3.732336026260391*^9}, {3.737958413314539*^9, 
  3.7379584165958652`*^9}, {3.7379589102968626`*^9, 3.7379589144844418`*^9}}],

Cell[CellGroupData[{

Cell["Defining parameter values and global simulation parameters", \
"Subsubsection",
 CellChangeTimes->{{3.7323360232584224`*^9, 3.73233603410437*^9}, {
  3.732336120509369*^9, 3.732336128370386*^9}, {3.7323362192289944`*^9, 
  3.7323362309026337`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"params", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", "\[Rule]", "0.1"}], ",", 
     RowBox[{"e1", "\[Rule]", "0.33"}], ",", 
     RowBox[{"e2", "\[Rule]", "0.33"}], ",", 
     RowBox[{"r1", "\[Rule]", "0.5"}], ",", 
     RowBox[{"r2", "\[Rule]", "0.5"}], ",", 
     RowBox[{"a1", "\[Rule]", "5"}], ",", 
     RowBox[{"a2", "\[Rule]", "5"}], ",", 
     RowBox[{"h1", "\[Rule]", "1"}], ",", 
     RowBox[{"h2", "\[Rule]", "1"}], ",", 
     RowBox[{"theta", "\[Rule]", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sys1", "=", 
   RowBox[{"SysFitnessDependent", "/.", "params"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", "50000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numsteps", "=", "20000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numvaluesM", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numvaluesK", "=", "21"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"minK", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxK", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"minM", "=", 
   RowBox[{"-", "3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxM", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7320133188232527`*^9, 3.7320133188232527`*^9}, {
   3.7320134089947767`*^9, 3.732013411791725*^9}, {3.732013473584118*^9, 
   3.7320135000263968`*^9}, {3.7323356355200157`*^9, 
   3.7323356552397146`*^9}, {3.732335688914898*^9, 3.7323356904149694`*^9}, 
   3.7323359352763615`*^9, 3.732335974454573*^9, {3.7323360454033327`*^9, 
   3.7323361687049174`*^9}, {3.7323362463717318`*^9, 3.7323362465279427`*^9}, 
   3.7323377955414143`*^9, {3.732337840061029*^9, 3.732337840592286*^9}, {
   3.732337971581377*^9, 3.7323379789095926`*^9}, {3.7323382627947397`*^9, 
   3.732338279125016*^9}, 3.7323384821748285`*^9, 3.732338671949501*^9, 
   3.7323391185066075`*^9, 3.732339442938012*^9, {3.7379539999194174`*^9, 
   3.7379541208356905`*^9}, {3.737957697517645*^9, 3.7379577192111263`*^9}, {
   3.7379579387247047`*^9, 3.7379579433654065`*^9}, {3.7379589177344904`*^9, 
   3.7379589390317087`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Arrays for storing simulated time series", "Subsubsection",
 CellChangeTimes->{{3.732336310051952*^9, 3.732336317631905*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"x1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xvalues", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"yvalues", "=", 
    RowBox[{"Array", "[", 
     RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"timeseries", " ", "on", " ", "log", " ", "scale"}], ",", " ", 
    RowBox[{
    "and", " ", "differences", " ", "between", " ", "two", " ", 
     "timepoints"}], ",", " ", 
    RowBox[{
    "for", " ", "calculation", " ", "of", " ", "correlation", " ", 
     "coefficients"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logx1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logx2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logy1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logy2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diffx1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diffx2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diffy1values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"diffy2values", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", "numsteps"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.7323363287571*^9, {3.7323363598244133`*^9, 3.7323364063004847`*^9}, 
   3.7323383484753594`*^9, {3.7379541232149906`*^9, 3.737954135431669*^9}, {
   3.737954184867968*^9, 3.737954191156988*^9}, 3.73795686899143*^9, {
   3.737957031270731*^9, 3.7379570418555694`*^9}, {3.7379572141234903`*^9, 
   3.737957235668403*^9}, {3.73795746662475*^9, 3.737957502154558*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining arrays of output values", "Subsubsection",
 CellChangeTimes->{{3.732336203242155*^9, 3.7323362160101323`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"meanprey", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"meanpred", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"stdevprey", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"stdevpred", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cvprey", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cvpred", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"correlationprey", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"correlationpred", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numvaluesM", "+", "1"}], ",", 
       RowBox[{"numvaluesK", "+", "1"}]}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7323362429184756`*^9, 3.732336321803821*^9}, {
   3.732336423069455*^9, 3.7323365046889153`*^9}, {3.7323367871968145`*^9, 
   3.732336791276896*^9}, {3.732337510433137*^9, 3.7323375538140297`*^9}, {
   3.7323379080885763`*^9, 3.7323379357493243`*^9}, {3.7323383507097507`*^9, 
   3.7323383518816357`*^9}, 3.737954417604087*^9, {3.737954596407192*^9, 
   3.7379546652891273`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Simulation on a grid of parameter values for migration rate and carrying \
capacity\
\>", "Subsubsection",
 CellChangeTimes->{{3.732336529925578*^9, 3.732336550414056*^9}, {
  3.7379542038248253`*^9, 3.737954225297949*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "\[LessEqual]", 
     RowBox[{"numvaluesM", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "\[LessEqual]", 
       RowBox[{"numvaluesK", "+", "1"}]}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
        "substituting", " ", "values", " ", "for", " ", "mMax", " ", "and", 
         " ", "k"}], ",", " ", 
        RowBox[{
        "and", " ", "numerical", " ", "solving", " ", "of", " ", "the", " ", 
         "differential", " ", "equations"}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"z1", "=", 
        RowBox[{"minM", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"i", "-", "1"}], ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"maxM", "-", "minM"}], ")"}], "/", "numvaluesM"}]}]}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"z2", "=", 
        RowBox[{"minK", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"j", "-", "1"}], ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"maxK", "-", "minK"}], ")"}], "/", "numvaluesK"}]}]}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Sys2", "=", 
        RowBox[{"Sys1", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"mMax", "\[Rule]", 
            RowBox[{"10", "^", "z1"}]}], ",", 
           RowBox[{"k", "\[Rule]", "z2"}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"sol1", "=", 
        RowBox[{"NDSolve", "[", 
         RowBox[{"Sys2", ",", 
          RowBox[{"{", 
           RowBox[{"x1", ",", "x2", ",", "y1", ",", "y2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
          RowBox[{"PrecisionGoal", "\[Rule]", "13"}], ",", 
          RowBox[{"AccuracyGoal", "\[Rule]", "13"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"generating", " ", "timeseries"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"m", "=", "1"}], ",", 
         RowBox[{"m", "\[LessEqual]", 
          RowBox[{"numsteps", "+", "1"}]}], ",", 
         RowBox[{"m", "++"}], ",", 
         RowBox[{
          RowBox[{"n", "=", 
           RowBox[{"tmax", "-", "numsteps", "-", "1", "+", "m"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"x1", "[", "n", "]"}], "/.", "sol1"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"x2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"x2", "[", "n", "]"}], "/.", "sol1"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"xvalues", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"x1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "+", 
            RowBox[{"x2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"y1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"y1", "[", "n", "]"}], "/.", "sol1"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"y2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"y2", "[", "n", "]"}], "/.", "sol1"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"yvalues", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"y1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "+", 
            RowBox[{"y2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"logx1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{"Log10", "[", 
            RowBox[{"x1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"logx2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{"Log10", "[", 
            RowBox[{"x2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"logy1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{"Log10", "[", 
            RowBox[{"y1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"logy2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{"Log10", "[", 
            RowBox[{"y2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}], "]"}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"calculating", " ", "means"}], ",", " ", 
         RowBox[{"standard", " ", "deviations"}], ",", " ", 
         RowBox[{"and", " ", "coefficient", " ", "of", " ", "variation"}]}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"meanprey", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"Mean", "[", "xvalues", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"meanpred", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"Mean", "[", "yvalues", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"stdevprey", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"StandardDeviation", "[", "xvalues", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"stdevpred", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"StandardDeviation", "[", "yvalues", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cvprey", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"stdevprey", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], "/", 
         RowBox[{"meanprey", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cvpred", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"stdevpred", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], "/", 
         RowBox[{"meanpred", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "generate", " ", "difference", " ", "of", " ", "log", " ", "of", " ",
           "timeseries"}], ",", " ", 
         RowBox[{"for", " ", "calculation", " ", "of", " ", "correlation"}]}],
         "*)"}], "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"m", "=", "1"}], ",", 
         RowBox[{"m", "\[LessEqual]", "numsteps"}], ",", 
         RowBox[{"m", "++"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"diffx1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"logx1values", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"logx1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"diffx2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"logx2values", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"logx2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"diffy1values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"logy1values", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"logy1values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"diffy2values", "[", 
            RowBox[{"[", "m", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"logy2values", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"logy2values", "[", 
             RowBox[{"[", "m", "]"}], "]"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "calculation", " ", "of", " ", "correlation", " ", "coefficients", 
         " ", "for", " ", "prey", " ", "and", " ", "predator", " ", 
         "dynamics"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"correlationprey", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"Correlation", "[", 
         RowBox[{"diffx1values", ",", "diffx2values"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"correlationpred", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
        RowBox[{"Correlation", "[", 
         RowBox[{"diffy1values", ",", "diffy2values"}], "]"}]}], ";"}]}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "end", " ", "of", " ", "calculations", " ", "for", " ", "a", " ", 
        "single", " ", "simulation", " ", "run"}], ";", " ", 
       RowBox[{
       "return", " ", "to", " ", "the", " ", "next", " ", "iteration", " ", 
        "of", " ", "the", " ", "loop"}]}], "*)"}], "\[IndentingNewLine]", 
     "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.732336569433798*^9, 3.7323366852963533`*^9}, {
   3.7323367387850437`*^9, 3.7323369982084084`*^9}, {3.7323370286974297`*^9, 
   3.7323370394163523`*^9}, {3.732337092627457*^9, 3.7323371893742886`*^9}, {
   3.732337228409675*^9, 3.7323375071049304`*^9}, {3.7323375637845488`*^9, 
   3.7323377653169785`*^9}, {3.7323378445473537`*^9, 3.732337851406842*^9}, {
   3.7323380295549593`*^9, 3.7323380529640846`*^9}, {3.7323383607099037`*^9, 
   3.7323384162473373`*^9}, {3.7323385480137167`*^9, 3.732338548607476*^9}, {
   3.732338730457673*^9, 3.732338732332697*^9}, {3.7323388456466856`*^9, 
   3.732338852365546*^9}, {3.7379567773638945`*^9, 3.7379568081300282`*^9}, {
   3.7379568404050207`*^9, 3.737957128577719*^9}, {3.7379572405560355`*^9, 
   3.7379573991467075`*^9}, {3.7379574311509805`*^9, 
   3.7379574412563295`*^9}, {3.7379575091947007`*^9, 
   3.7379576202624826`*^9}, {3.7379577506325684`*^9, 3.7379577532684298`*^9}, 
   3.737957786409658*^9, {3.737957835316716*^9, 3.737957842160579*^9}, {
   3.7379579545842924`*^9, 3.7379579826629024`*^9}, {3.7379580199304314`*^9, 
   3.7379580200241632`*^9}, {3.7379588785462284`*^9, 3.737958883827609*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1920, 1117},
WindowMargins->{{1912, Automatic}, {Automatic, -8}},
CellContext->"plasticitymeanprop2d1`",
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (December 4, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 350, 5, 54, "Input"],
Cell[CellGroupData[{
Cell[933, 29, 218, 3, 70, "Section"],
Cell[CellGroupData[{
Cell[1176, 36, 179, 2, 49, "Subsection"],
Cell[1358, 40, 8895, 157, 92, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10290, 202, 177, 2, 49, "Subsection"],
Cell[10470, 206, 8851, 154, 172, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19358, 365, 166, 2, 49, "Subsection"],
Cell[19527, 369, 9177, 159, 172, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28741, 533, 166, 3, 49, "Subsection"],
Cell[28910, 538, 2438, 74, 92, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[31397, 618, 100, 1, 70, "Section"],
Cell[CellGroupData[{
Cell[31522, 623, 219, 3, 49, "Subsection"],
Cell[CellGroupData[{
Cell[31766, 630, 254, 4, 39, "Subsubsection"],
Cell[32023, 636, 2088, 45, 212, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34148, 686, 131, 1, 39, "Subsubsection"],
Cell[34282, 689, 2771, 73, 332, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37090, 767, 125, 1, 39, "Subsubsection"],
Cell[37218, 770, 2516, 77, 172, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39771, 852, 233, 5, 39, "Subsubsection"],
Cell[40007, 859, 12165, 293, 832, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[52221, 1158, 272, 3, 49, "Subsection"],
Cell[CellGroupData[{
Cell[52518, 1165, 295, 4, 39, "Subsubsection"],
Cell[52816, 1171, 2704, 59, 232, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55557, 1235, 131, 1, 39, "Subsubsection"],
Cell[55691, 1238, 2771, 73, 332, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58499, 1316, 125, 1, 39, "Subsubsection"],
Cell[58627, 1319, 2516, 77, 172, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61180, 1401, 233, 5, 39, "Subsubsection"],
Cell[61416, 1408, 12497, 299, 852, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[73962, 1713, 274, 3, 49, "Subsection"],
Cell[CellGroupData[{
Cell[74261, 1720, 254, 4, 39, "Subsubsection"],
Cell[74518, 1726, 2199, 49, 212, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76754, 1780, 131, 1, 39, "Subsubsection"],
Cell[76888, 1783, 2771, 73, 332, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79696, 1861, 125, 1, 39, "Subsubsection"],
Cell[79824, 1864, 2516, 77, 172, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82377, 1946, 233, 5, 39, "Subsubsection"],
Cell[82613, 1953, 12165, 293, 832, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
